@@ -6,7 +6,7 @@ echo "" 												>> $EXTENSION/build_order.txt
 [ ! -f /lib/libboost_atomic.so ] && echo "Installing boost" && extension --install boost && echo "Finished boost"
 [[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"
 [[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
-[ ! -f /opt/kf6/bin/kded6 ] && echo "Installing kde_framework" && extension --install kde_framework && echo "Finished kde_framework"
+[ ! -d /opt/kf6-6.14.0 ] && echo "Installing kde_framework:6.14.0" && extension --install kde_framework:6.14.0 && echo "Finished kde_framework:6.14.0"
 [ ! -d $KF6_PREFIX/lib/cmake/KF6KirigamiAddons ] && echo "Installing kirigami_addons" && extension --install kirigami_addons && echo "Finished kirigami_addons"
 [ ! -f /lib/libdisplay-info.so ] && echo "Installing libdisplay_info" && extension --install libdisplay_info && echo "Finished libdisplay_info"
 [[ $(command -v pwscore) == "" ]] && echo "Installing libpwquality" && extension --install libpwquality && echo "Finished libpwquality"
@@ -31,13 +31,13 @@ if [[ $INSTALL_RECOMMENDED != false ]]; then
 	[ ! -d /usr/share/GConf/gsettings ] && echo "Installing gsettings_desktop_schemas" && extension --install gsettings_desktop_schemas && echo "Finished gsettings_desktop_schemas"
 	[[ $(command -v canberra-gtk-play) == "" ]] && echo "Installing libcanberra" && extension --install libcanberra && echo "Finished libcanberra"
 	[[ $(command -v libinput) == "" ]] && echo "Installing libinput" && extension --install libinput && echo "Finished libinput"
-	#[[ $(command -v pcap-config) == "" ]] && echo "Installing libpcap" && extension --install libpcap && echo "Finished libpcap"
+	[[ $(command -v pcap-config) == "" ]] && echo "Installing libpcap" && extension --install libpcap && echo "Finished libpcap"
 	[[ $(command -v libwacom-list-devices) == "" ]] && echo "Installing libwacom" && extension --install libwacom && echo "Finished libwacom"
 	#[[ $(command -v xsetwacom) == "" ]] && echo "Installing xorg_wacom_driver" && extension --install xorg_wacom_driver && echo "Finished xorg_wacom_driver"
 	[[ $(command -v pam_namespace_helper) == "" ]] && echo "Installing linux_pam" && extension --install linux_pam && echo "Finished linux_pam"
 	[[ $(command -v fancontrol) == "" ]] && echo "Installing lm_sensors" && extension --install lm_sensors && echo "Finished lm_sensors"
-	#[ ! -d /usr/share/icons/oxygen ] && echo "Installing oxygen_icons" && extension --install oxygen_icons && echo "Finished oxygen_icons"
-	#[[ $(command -v lspci) == "" ]] && echo "Installing pciutils" && extension --install pciutils && echo "Finished pciutils"
+	[ ! -d /usr/share/icons/oxygen ] && echo "Installing oxygen_icons" && extension --install oxygen_icons && echo "Finished oxygen_icons"
+	[[ $(command -v lspci) == "" ]] && echo "Installing pciutils" && extension --install pciutils && echo "Finished pciutils"
 	#[[ $(command -v powerprofilesctl) == "" ]] && echo "Installing power_profiles_daemon" && extension --install power_profiles_daemon && echo "Finished power_profiles_daemon"
 	[ ! -d /usr/lib/python*/site-packages/psutil-* ] && echo "Installing py_psutil" && extension --install py_psutil && echo "Finished py_psutil"
 	[ ! -d /usr/lib/python*/site-packages/pygdbmi-* ] && echo "Installing py_pygdbmi" && extension --install py_pygdbmi && echo "Finished py_pygdbmi"
